@@ -2,7 +2,7 @@
  * \file MGRS.hpp
  * \brief Header for GeographicLib::MGRS class
  *
- * Copyright (c) Charles Karney (2008-2023) <karney@alum.mit.edu> and licensed
+ * Copyright (c) Charles Karney (2008-2024) <karney@alum.mit.edu> and licensed
  * under the MIT/X11 License.  For more information, see
  * https://geographiclib.sourceforge.io/
  **********************************************************************/
@@ -13,12 +13,6 @@
 #include <GeographicLib/Constants.hpp>
 #include <GeographicLib/UTMUPS.hpp>
 
-#if defined(_MSC_VER)
-// Squelch warnings about dll vs string
-#  pragma warning (push)
-#  pragma warning (disable: 4251)
-#endif
-
 namespace GeographicLib {
 
   /**
@@ -88,19 +82,17 @@ namespace GeographicLib {
     static const int maxeasting_[4];
     static const int minnorthing_[4];
     static const int maxnorthing_[4];
-    enum {
-      base_ = 10,
-      // Top-level tiles are 10^5 m = 100 km on a side
-      tilelevel_ = 5,
-      // Period of UTM row letters
-      utmrowperiod_ = 20,
-      // Row letters are shifted by 5 for even zones
-      utmevenrowshift_ = 5,
-      // Maximum precision is um
-      maxprec_ = 5 + 6,
-      // For generating digits at maxprec
-      mult_ = 1000000
-    };
+    static constexpr int base_ = 10;
+    // Top-level tiles are 10^5 m = 100 km on a side
+    static constexpr int tilelevel_ = 5;
+    // Period of UTM row letters
+    static constexpr int utmrowperiod_ = 20;
+    // Row letters are shifted by 5 for even zones
+    static constexpr int utmevenrowshift_ = 5;
+    // Maximum precision is um
+    static constexpr int maxprec_ = 5 + 6;
+    // For generating digits at maxprec
+    static constexpr int mult_ = 1000000;
     static void CheckCoords(bool utmp, bool& northp, real& x, real& y);
     static int UTMRow(int iband, int icol, int irow);
 
@@ -118,7 +110,7 @@ namespace GeographicLib {
     // function isn't currently used.
     static int ApproxLatitudeBand(real y) {
       // northing at tile center in units of tile = 100km
-      using std::floor; using std::fabs; using std::fmin;
+      using std::floor, std::fabs, std::fmin;
       real ya = floor( fmin(real(88), fabs(y / real(tile_))) ) + real(0.5);
       // convert to lat (mult by 90/100) and then to band (divide by 8)
       // the +1 fine tunes the boundary between bands 3 and 4
@@ -137,24 +129,22 @@ namespace GeographicLib {
       // X 9  80:94  15
       return y >= 0 ? b : -(b + 1);
     }
-    // UTMUPS accesses these enums
-    enum {
-      tile_ = 100000,            // Size MGRS blocks
-      minutmcol_ = 1,
-      maxutmcol_ = 9,
-      minutmSrow_ = 10,
-      maxutmSrow_ = 100,         // Also used for UTM S false northing
-      minutmNrow_ = 0,           // Also used for UTM N false northing
-      maxutmNrow_ = 95,
-      minupsSind_ = 8,           // These 4 ind's apply to easting and northing
-      maxupsSind_ = 32,
-      minupsNind_ = 13,
-      maxupsNind_ = 27,
-      upseasting_ = 20,          // Also used for UPS false northing
-      utmeasting_ = 5,           // UTM false easting
-      // Difference between S hemisphere northing and N hemisphere northing
-      utmNshift_ = (maxutmSrow_ - minutmNrow_) * tile_
-    };
+    // UTMUPS accesses these constants
+    static constexpr int tile_ = 100000;    // Size MGRS blocks
+    static constexpr int minutmcol_ = 1;
+    static constexpr int maxutmcol_ = 9;
+    static constexpr int minutmSrow_ = 10;
+    static constexpr int maxutmSrow_ = 100; // Also used for UTM S false northing
+    static constexpr int minutmNrow_ = 0;   // Also used for UTM N false northing
+    static constexpr int maxutmNrow_ = 95;
+    static constexpr int minupsSind_ = 8;   // These 4 ind's apply to easting and northing
+    static constexpr int maxupsSind_ = 32;
+    static constexpr int minupsNind_ = 13;
+    static constexpr int maxupsNind_ = 27;
+    static constexpr int upseasting_ = 20;  // Also used for UPS false northing
+    static constexpr int utmeasting_ = 5;   // UTM false easting
+    // Difference between S hemisphere northing and N hemisphere northing
+    static constexpr int utmNshift_ = (maxutmSrow_ - minutmNrow_) * tile_;
     MGRS() = delete;            // Disable constructor
 
   public:
@@ -375,8 +365,4 @@ namespace GeographicLib {
 
 } // namespace GeographicLib
 
-#if defined(_MSC_VER)
-#  pragma warning (pop)
-#endif
-
 #endif  // GEOGRAPHICLIB_MGRS_HPP
