@@ -2,7 +2,7 @@
  * \file NormalGravity.hpp
  * \brief Header for GeographicLib::NormalGravity class
  *
- * Copyright (c) Charles Karney (2011-2022) <charles@karney.com> and licensed
+ * Copyright (c) Charles Karney (2011-2022) <karney@alum.mit.edu> and licensed
  * under the MIT/X11 License.  For more information, see
  * https://geographiclib.sourceforge.io/
  **********************************************************************/
@@ -21,7 +21,7 @@ namespace GeographicLib {
    * "Normal" gravity refers to an idealization of the earth which is modeled
    * as an rotating ellipsoid.  The eccentricity of the ellipsoid, the rotation
    * speed, and the distribution of mass within the ellipsoid are such that the
-   * ellipsoid is a "level ellipoid", a surface of constant potential
+   * ellipsoid is a "level ellipsoid", a surface of constant potential
    * (gravitational plus centrifugal).  The acceleration due to gravity is
    * therefore perpendicular to the surface of the ellipsoid.
    *
@@ -30,7 +30,7 @@ namespace GeographicLib {
    * the mass is assumed to be to concentrated on a "focal disc" of radius,
    * (<i>a</i><sup>2</sup> &minus; <i>b</i><sup>2</sup>)<sup>1/2</sup>, where
    * \e a is the equatorial radius of the ellipsoid and \e b is its polar
-   * semi-axis.  In the case of an oblate ellipsoid, the mass is concentrated
+   * semiaxis.  In the case of an oblate ellipsoid, the mass is concentrated
    * on a "focal rod" of length 2(<i>b</i><sup>2</sup> &minus;
    * <i>a</i><sup>2</sup>)<sup>1/2</sup>.  As a result the potential is well
    * defined everywhere.
@@ -65,10 +65,11 @@ namespace GeographicLib {
    *   di rotazione, Mem. Soc. Astron. Ital, <b>4</b>, 541--599 (1929).
    * - W. A. Heiskanen and H. Moritz, Physical Geodesy (Freeman, San
    *   Francisco, 1967), Secs. 1-19, 2-7, 2-8 (2-9, 2-10), 6-2 (6-3).
+   *   https://archive.org/details/HeiskanenMoritz1967PhysicalGeodesy
    * - B. Hofmann-Wellenhof, H. Moritz, Physical Geodesy (Second edition,
-   *   Springer, 2006) https://doi.org/10.1007/978-3-211-33545-1
+   *   Springer, 2006). https://doi.org/10.1007/978-3-211-33545-1
    * - H. Moritz, Geodetic Reference System 1980, J. Geodesy 54(3), 395-405
-   *   (1980) https://doi.org/10.1007/BF02521480
+   *   (1980). https://doi.org/10.1007/BF02521480
    *
    * For more information on normal gravity see \ref normalgravity.
    *
@@ -90,8 +91,7 @@ namespace GeographicLib {
       //
       // Require x >= -1.  Best to call with alt, s.t. x >= 0; this results in
       // a call to atan, instead of asin, or to asinh, instead of atanh.
-      using std::sqrt; using std::fabs; using std::atan; using std::asin;
-      using std::asinh; using std::atanh;
+      using std::sqrt, std::fabs, std::atan, std::asin, std::asinh, std::atanh;
       real z = sqrt(fabs(x));
       return x == 0 ? 1 :
         (alt ?
@@ -129,7 +129,7 @@ namespace GeographicLib {
      * The shape of the ellipsoid can be given in one of two ways:
      * - geometrically (\e geomtricp = true), the ellipsoid is defined by the
      *   flattening \e f = (\e a &minus; \e b) / \e a, where \e a and \e b are
-     *   the equatorial radius and the polar semi-axis.  The parameters should
+     *   the equatorial radius and the polar semiaxis.  The parameters should
      *   obey \e a &gt; 0, \e f &lt; 1.  There are no restrictions on \e GM or
      *   \e omega, in particular, \e GM need not be positive.
      * - physically (\e geometricp = false), the ellipsoid is defined by the
