@@ -25,8 +25,8 @@
 #endif
 
 #if defined(_MSC_VER)
-// Squelch warnings about unsafe use of getenv and enum-float expressions
-#  pragma warning (disable: 4996 5055)
+// Squelch warnings about unsafe use of getenv
+#  pragma warning (disable: 4996)
 #endif
 
 namespace GeographicLib {
@@ -304,7 +304,6 @@ namespace GeographicLib {
   }
 
   Math::real Geoid::height(real lat, real lon) const {
-    using std::isnan;           // Needed for Centos 7, ubuntu 14
     lat = Math::LatFix(lat);
     if (isnan(lat) || isnan(lon)) {
       return Math::NaN();
