@@ -32,7 +32,6 @@ static int checkEquals(T x, T y, T d) {
 }
 
 static int checkNaN(T x) {
-  using std::isnan;             // Needed for Centos 7, ubuntu 14
   if (isnan(x))
     return 0;
   cout << "checkNaN fails\n";
@@ -184,6 +183,7 @@ static int Planimeter29() {
 }
 
 int main() {
+  Utility::set_digits();
   int n = 0, i;
 
   i = Planimeter15(); n += i;
